F

Struct F 

pub struct F(/* private fields */);
Block Device Feature Bits

Implementations

Source

impl F

pub const SIZE_MAX: Self

Maximum size of any single segment is

pub const SEG_MAX: Self

Maximum number of segments in a request is in seg_max.

pub const GEOMETRY: Self

Disk-style geometry specified in geometry.

pub const RO: Self

Device is read-only.

pub const BLK_SIZE: Self

Block size of disk is in blk_size.

pub const FLUSH: Self

Cache flush command support.

pub const TOPOLOGY: Self

Device exports information on optimal I/O alignment.

pub const CONFIG_WCE: Self

Device can toggle its cache between writeback and writethrough modes.

pub const MQ: Self

Device supports multiqueue.

pub const DISCARD: Self

Device can support discard command, maximum discard sectors size in max_discard_sectors and maximum discard segment number in max_discard_seg.

pub const WRITE_ZEROES: Self

Device can support write zeroes command, maximum write zeroes sectors size in max_write_zeroes_sectors and maximum write zeroes segment number in max_write_zeroes_seg.

pub const LIFETIME: Self

Device supports providing storage lifetime information.

pub const SECURE_ERASE: Self

Device supports secure erase command, maximum erase sectors count in max_secure_erase_sectors and maximum erase segment number in max_secure_erase_seg.

pub const ZONED: Self

Device is a Zoned Block Device, that is, a device that follows the zoned storage device behavior that is also supported by industry standards such as the T10 Zoned Block Command standard (ZBC r05) or the NVMe(TM) NVM Express Zoned Namespace Command Set Specification 1.1b (ZNS). For brevity, these standard documents are referred as “ZBD standards” from this point on in the text.

pub const INDIRECT_DESC: Self

Device-independent Bit. See virtio::F::INDIRECT_DESC.

pub const EVENT_IDX: Self

Device-independent Bit. See virtio::F::EVENT_IDX.

pub const VERSION_1: Self

Device-independent Bit. See virtio::F::VERSION_1.

pub const ACCESS_PLATFORM: Self

Device-independent Bit. See virtio::F::ACCESS_PLATFORM.

pub const RING_PACKED: Self

Device-independent Bit. See virtio::F::RING_PACKED.

pub const IN_ORDER: Self

Device-independent Bit. See virtio::F::IN_ORDER.

pub const ORDER_PLATFORM: Self

Device-independent Bit. See virtio::F::ORDER_PLATFORM.

pub const SR_IOV: Self

Device-independent Bit. See virtio::F::SR_IOV.

pub const NOTIFICATION_DATA: Self

Device-independent Bit. See virtio::F::NOTIFICATION_DATA.

pub const NOTIF_CONFIG_DATA: Self

Device-independent Bit. See virtio::F::NOTIF_CONFIG_DATA.

pub const RING_RESET: Self

Device-independent Bit. See virtio::F::RING_RESET.

pub const ADMIN_VQ: Self

Device-independent Bit. See virtio::F::ADMIN_VQ.

pub const SUSPEND: Self

Device-independent Bit. See virtio::F::SUSPEND.

Source

impl F

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> le128

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: le128) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: le128) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: le128) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl F

pub fn iter(&self) -> Iter<Self>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub fn iter_names(&self) -> IterNames<Self>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.