pub struct F(/* private fields */);Expand description
Network Device Feature Bits
Implementations
Sourceimpl F
impl F
Sourcepub const GUEST_CSUM: Self
pub const GUEST_CSUM: Self
Driver handles packets with partial checksum.
Sourcepub const CTRL_GUEST_OFFLOADS: Self
pub const CTRL_GUEST_OFFLOADS: Self
Control channel offloads reconfiguration support.
Sourcepub const MTU: Self
pub const MTU: Self
Device maximum MTU reporting is supported. If offered by the device, device advises driver about the value of its maximum MTU. If negotiated, the driver uses mtu as the maximum MTU value.
Sourcepub const GUEST_TSO4: Self
pub const GUEST_TSO4: Self
Driver can receive TSOv4.
Sourcepub const GUEST_TSO6: Self
pub const GUEST_TSO6: Self
Driver can receive TSOv6.
Sourcepub const CTRL_RX_EXTRA: Self
pub const CTRL_RX_EXTRA: Self
Control channel RX extra mode support.
Sourcepub const GUEST_ANNOUNCE: Self
pub const GUEST_ANNOUNCE: Self
Driver can send gratuitous packets.
Sourcepub const CTRL_MAC_ADDR: Self
pub const CTRL_MAC_ADDR: Self
Set MAC address through control channel.
Sourcepub const DEVICE_STATS: Self
pub const DEVICE_STATS: Self
Device can provide device-level statistics to the driver through the control virtqueue.
Sourcepub const HASH_TUNNEL: Self
pub const HASH_TUNNEL: Self
Device supports inner header hash for encapsulated packets.
Sourcepub const VQ_NOTF_COAL: Self
pub const VQ_NOTF_COAL: Self
Device supports virtqueue notification coalescing.
Sourcepub const GUEST_USO4: Self
pub const GUEST_USO4: Self
Driver can receive USOv4 packets.
Sourcepub const GUEST_USO6: Self
pub const GUEST_USO6: Self
Driver can receive USOv6 packets.
Sourcepub const HOST_USO: Self
pub const HOST_USO: Self
Device can receive USO packets. Unlike UFO (fragmenting the packet) the USO splits large UDP packet to several segments when each of these smaller packets has UDP header.
Sourcepub const HASH_REPORT: Self
pub const HASH_REPORT: Self
Device can report per-packet hash value and a type of calculated hash.
Sourcepub const GUEST_HDRLEN: Self
pub const GUEST_HDRLEN: Self
Driver can provide the exact hdr_len value. Device benefits from knowing the exact header length.
Sourcepub const RSS: Self
pub const RSS: Self
Device supports RSS (receive-side scaling) with Toeplitz hash calculation and configurable hash parameters for receive steering.
Sourcepub const RSC_EXT: Self
pub const RSC_EXT: Self
Device can process duplicated ACKs and report number of coalesced segments and duplicated ACKs.
Sourcepub const STANDBY: Self
pub const STANDBY: Self
Device may act as a standby for a primary device with the same MAC address.
Sourcepub const SPEED_DUPLEX: Self
pub const SPEED_DUPLEX: Self
Device reports speed and duplex.
Sourcepub const RSS_CONTEXT: Self
pub const RSS_CONTEXT: Self
Device supports multiple RSS contexts.
Sourcepub const GUEST_UDP_TUNNEL_GSO: Self
pub const GUEST_UDP_TUNNEL_GSO: Self
Driver can receive GSO packets carried by a UDP tunnel.
Sourcepub const GUEST_UDP_TUNNEL_GSO_CSUM: Self
pub const GUEST_UDP_TUNNEL_GSO_CSUM: Self
Driver handles packets carried by a UDP tunnel with partial csum for the outer header.
Sourcepub const HOST_UDP_TUNNEL_GSO: Self
pub const HOST_UDP_TUNNEL_GSO: Self
Device can receive GSO packets carried by a UDP tunnel.
Sourcepub const HOST_UDP_TUNNEL_GSO_CSUM: Self
pub const HOST_UDP_TUNNEL_GSO_CSUM: Self
Device handles packets carried by a UDP tunnel with partial csum for the outer header.
Sourcepub const OUT_NET_HEADER: Self
pub const OUT_NET_HEADER: Self
Driver can provide the start of
outer_nh_offset value. Device gains advantage by not reading packet
to calculate outer network header offset.
Sourcepub const IPSEC: Self
pub const IPSEC: Self
Device supports inline IPsec processing.
struct virtio_net_hdr size expands upto field sturct ipsec_resource_hdr
when VIRTIO_NET_F_IPSEC is negotiated. When a device offers IPsec feature, it SHOULD
also offer the VIRTIO_NET_F_OUT_NET_HEADER feature.
Sourcepub const INDIRECT_DESC: Self
pub const INDIRECT_DESC: Self
Device-independent Bit. See virtio::F::INDIRECT_DESC.
Sourcepub const EVENT_IDX: Self
pub const EVENT_IDX: Self
Device-independent Bit. See virtio::F::EVENT_IDX.
Sourcepub const VERSION_1: Self
pub const VERSION_1: Self
Device-independent Bit. See virtio::F::VERSION_1.
Sourcepub const ACCESS_PLATFORM: Self
pub const ACCESS_PLATFORM: Self
Device-independent Bit. See virtio::F::ACCESS_PLATFORM.
Sourcepub const RING_PACKED: Self
pub const RING_PACKED: Self
Device-independent Bit. See virtio::F::RING_PACKED.
Sourcepub const IN_ORDER: Self
pub const IN_ORDER: Self
Device-independent Bit. See virtio::F::IN_ORDER.
Sourcepub const ORDER_PLATFORM: Self
pub const ORDER_PLATFORM: Self
Device-independent Bit. See virtio::F::ORDER_PLATFORM.
Sourcepub const SR_IOV: Self
pub const SR_IOV: Self
Device-independent Bit. See virtio::F::SR_IOV.
Sourcepub const NOTIFICATION_DATA: Self
pub const NOTIFICATION_DATA: Self
Device-independent Bit. See virtio::F::NOTIFICATION_DATA.
Sourcepub const NOTIF_CONFIG_DATA: Self
pub const NOTIF_CONFIG_DATA: Self
Device-independent Bit. See virtio::F::NOTIF_CONFIG_DATA.
Sourcepub const RING_RESET: Self
pub const RING_RESET: Self
Device-independent Bit. See virtio::F::RING_RESET.
Sourcepub const ADMIN_VQ: Self
pub const ADMIN_VQ: Self
Device-independent Bit. See virtio::F::ADMIN_VQ.
Sourcepub const SUSPEND: Self
pub const SUSPEND: Self
Device-independent Bit. See virtio::F::SUSPEND.
Sourceimpl F
impl F
Sourcepub const fn bits(&self) -> le128
pub const fn bits(&self) -> le128
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: le128) -> Option<Self>
pub const fn from_bits(bits: le128) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: le128) -> Self
pub const fn from_bits_truncate(bits: le128) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: le128) -> Self
pub const fn from_bits_retain(bits: le128) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl F
impl F
Sourcepub fn iter(&self) -> Iter<Self> ⓘ
pub fn iter(&self) -> Iter<Self> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub fn iter_names(&self) -> IterNames<Self> ⓘ
pub fn iter_names(&self) -> IterNames<Self> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.