pub struct F(/* private fields */);Expand description
Block Device Feature Bits
Implementations
Sourceimpl F
impl F
Sourcepub const CONFIG_WCE: Self
pub const CONFIG_WCE: Self
Device can toggle its cache between writeback and writethrough modes.
Sourcepub const DISCARD: Self
pub const DISCARD: Self
Device can support discard command, maximum
discard sectors size in max_discard_sectors and maximum discard
segment number in max_discard_seg.
Sourcepub const WRITE_ZEROES: Self
pub const WRITE_ZEROES: Self
Device can support write zeroes command,
maximum write zeroes sectors size in max_write_zeroes_sectors and
maximum write zeroes segment number in max_write_zeroes_seg.
Sourcepub const SECURE_ERASE: Self
pub const SECURE_ERASE: Self
Device supports secure erase command,
maximum erase sectors count in max_secure_erase_sectors and
maximum erase segment number in max_secure_erase_seg.
Sourcepub const ZONED: Self
pub const ZONED: Self
Device is a Zoned Block Device, that is, a device that follows the zoned storage device behavior that is also supported by industry standards such as the T10 Zoned Block Command standard (ZBC r05) or the NVMe(TM) NVM Express Zoned Namespace Command Set Specification 1.1b (ZNS). For brevity, these standard documents are referred as “ZBD standards” from this point on in the text.
Sourcepub const INDIRECT_DESC: Self
pub const INDIRECT_DESC: Self
Device-independent Bit. See virtio::F::INDIRECT_DESC.
Sourcepub const EVENT_IDX: Self
pub const EVENT_IDX: Self
Device-independent Bit. See virtio::F::EVENT_IDX.
Sourcepub const VERSION_1: Self
pub const VERSION_1: Self
Device-independent Bit. See virtio::F::VERSION_1.
Sourcepub const ACCESS_PLATFORM: Self
pub const ACCESS_PLATFORM: Self
Device-independent Bit. See virtio::F::ACCESS_PLATFORM.
Sourcepub const RING_PACKED: Self
pub const RING_PACKED: Self
Device-independent Bit. See virtio::F::RING_PACKED.
Sourcepub const IN_ORDER: Self
pub const IN_ORDER: Self
Device-independent Bit. See virtio::F::IN_ORDER.
Sourcepub const ORDER_PLATFORM: Self
pub const ORDER_PLATFORM: Self
Device-independent Bit. See virtio::F::ORDER_PLATFORM.
Sourcepub const SR_IOV: Self
pub const SR_IOV: Self
Device-independent Bit. See virtio::F::SR_IOV.
Sourcepub const NOTIFICATION_DATA: Self
pub const NOTIFICATION_DATA: Self
Device-independent Bit. See virtio::F::NOTIFICATION_DATA.
Sourcepub const NOTIF_CONFIG_DATA: Self
pub const NOTIF_CONFIG_DATA: Self
Device-independent Bit. See virtio::F::NOTIF_CONFIG_DATA.
Sourcepub const RING_RESET: Self
pub const RING_RESET: Self
Device-independent Bit. See virtio::F::RING_RESET.
Sourcepub const ADMIN_VQ: Self
pub const ADMIN_VQ: Self
Device-independent Bit. See virtio::F::ADMIN_VQ.
Sourcepub const SUSPEND: Self
pub const SUSPEND: Self
Device-independent Bit. See virtio::F::SUSPEND.
Sourceimpl F
impl F
Sourcepub const fn bits(&self) -> le128
pub const fn bits(&self) -> le128
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: le128) -> Option<Self>
pub const fn from_bits(bits: le128) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: le128) -> Self
pub const fn from_bits_truncate(bits: le128) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: le128) -> Self
pub const fn from_bits_retain(bits: le128) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl F
impl F
Sourcepub fn iter(&self) -> Iter<Self> ⓘ
pub fn iter(&self) -> Iter<Self> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub fn iter_names(&self) -> IterNames<Self> ⓘ
pub fn iter_names(&self) -> IterNames<Self> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.